summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:18:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:18:40 -0600
commit82072ef281de2d5948a42fb69ae800d47e0800be (patch)
treebe82dd63affaf693c5e0857c997fa9589d344cc2 /quanta/parts/kafka
parent93ec82602aa008218cc1ee075ff13d65b3a317ea (diff)
downloadtdewebdev-82072ef281de2d5948a42fb69ae800d47e0800be.tar.gz
tdewebdev-82072ef281de2d5948a42fb69ae800d47e0800be.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'quanta/parts/kafka')
-rw-r--r--quanta/parts/kafka/DESIGN8
-rw-r--r--quanta/parts/kafka/domtreeview.cpp2
-rw-r--r--quanta/parts/kafka/kafkahtmlpart.cpp26
-rw-r--r--quanta/parts/kafka/kafkahtmlpart.h14
-rw-r--r--quanta/parts/kafka/undoredo.cpp8
-rw-r--r--quanta/parts/kafka/wkafkapart.cpp12
-rw-r--r--quanta/parts/kafka/wkafkapart.h2
7 files changed, 36 insertions, 36 deletions
diff --git a/quanta/parts/kafka/DESIGN b/quanta/parts/kafka/DESIGN
index eabfd4e1..2f9537a2 100644
--- a/quanta/parts/kafka/DESIGN
+++ b/quanta/parts/kafka/DESIGN
@@ -14,8 +14,8 @@ Summary:
If you find an error (shouldn't be so hard ;-), could you report me please?
1) History
-In early 2003, I was looking for a good HTML WYSIWYG editor, and I didn't find what I wanted! So I decided to code one. After a quick search, I've found a dead project, Kafka, in kdenonbeta, which was supposed to become an full-featured WYSIWYG editor based on khtml. But at this time (2000-2001 I think) khtml wasn't ready. So it was abandonned.
-Meanwhile khtml have been greatly improved, partially thanks to the Apple Safari merging. Then I started to hack kafka a bit, adding basic cursor navigation, insertion/deletion, and so on... But I quickly realised that it would be too hard and too long for me alone to come to a decent editor. So I was looking to join an existing project, and I choose Quanta+, basically because it was (and still is, in my humble opinion) the best HTML editor in the KDE environment.
+In early 2003, I was looking for a good HTML WYSIWYG editor, and I didn't find what I wanted! So I decided to code one. After a quick search, I've found a dead project, Kafka, in kdenonbeta, which was supposed to become an full-featured WYSIWYG editor based on tdehtml. But at this time (2000-2001 I think) tdehtml wasn't ready. So it was abandonned.
+Meanwhile tdehtml have been greatly improved, partially thanks to the Apple Safari merging. Then I started to hack kafka a bit, adding basic cursor navigation, insertion/deletion, and so on... But I quickly realised that it would be too hard and too long for me alone to come to a decent editor. So I was looking to join an existing project, and I choose Quanta+, basically because it was (and still is, in my humble opinion) the best HTML editor in the KDE environment.
It seemed I came to Quanta+ exactly at the best time: they were considering to add WYSIWYG capabilities! So for now one year, I've been coded VPL during my free time, and I am not far from a stable status.
@@ -57,7 +57,7 @@ HTML
The Node class handle the pointers to the parent, next, previous and first child Node. *Each* Node has a valid pointer to a Tag. The Tag takes care to remember all the information concerning the Tag itself, like the attributes, the type, etc...)
One QTag per Element is created from the .tag files when Quanta is started. Each QTag contains all the DTD information about the Tag. E.g. the "IMG" Qtag says that it is a single Tag, and what are its attributes. You can get a QTag with QuantaCommon::tagFromDTD, but don't delete the QTag!
-Now to khtml. The class KHTMLPart is the HTML renderer widget of konqueror. It internally works with a Node Tree (another? Yep!) but these Nodes are real DOM::Nodes. (From now, I will call it the DOM::Node tree) Each of the DOM Nodes is khtml-internally linked to a rendering Node i.e. a change made to one DOM::Node will update the HTML rendering cf /path/to/kde/include/dom/*.h and also in the tdelibs cvs module, cf the nice tdelibs/khtml/DESIGN.html. WARNING about DOM::Nodes, they are just interfaces!!
+Now to tdehtml. The class KHTMLPart is the HTML renderer widget of konqueror. It internally works with a Node Tree (another? Yep!) but these Nodes are real DOM::Nodes. (From now, I will call it the DOM::Node tree) Each of the DOM Nodes is tdehtml-internally linked to a rendering Node i.e. a change made to one DOM::Node will update the HTML rendering cf /path/to/kde/include/dom/*.h and also in the tdelibs cvs module, cf the nice tdelibs/tdehtml/DESIGN.html. WARNING about DOM::Nodes, they are just interfaces!!
@@ -73,7 +73,7 @@ Then when a change is made to the source file, Parser::rebuild is called and syn
5) VPL classes.
VPL has several classes, but note sometimes it is not really object oriented, but I will clean up soon.
-* KafkaWidget(kafkahtmlpart.[h|cpp]): Derived from KHTMLPart, it uses the caret mode implemented by Leo Savernik in khtml (that means we don't have to care about cursor navigation). It handles every keypress in order to edit the widget (backspace/delete/return/<insertion of a letter>) and modify only the DOM::Node tree (not the Node tree).
+* KafkaWidget(kafkahtmlpart.[h|cpp]): Derived from KHTMLPart, it uses the caret mode implemented by Leo Savernik in tdehtml (that means we don't have to care about cursor navigation). It handles every keypress in order to edit the widget (backspace/delete/return/<insertion of a letter>) and modify only the DOM::Node tree (not the Node tree).
* KafkaDocument(wkafkapart.[h|cpp]): It takes care to load the DOM::Node tree from the Node tree, and when a change is made to the DOM::Node tree, it apply it in the Node tree. It basically takes care of the synchronization of the trees.
diff --git a/quanta/parts/kafka/domtreeview.cpp b/quanta/parts/kafka/domtreeview.cpp
index 5ed55a1b..0b1951f9 100644
--- a/quanta/parts/kafka/domtreeview.cpp
+++ b/quanta/parts/kafka/domtreeview.cpp
@@ -19,7 +19,7 @@
#ifdef HEAVY_DEBUG
#include <kdebug.h>
-#include <khtml_part.h>
+#include <tdehtml_part.h>
#include <klocale.h>
#include <tqstring.h>
#include <tqlayout.h>
diff --git a/quanta/parts/kafka/kafkahtmlpart.h b/quanta/parts/kafka/kafkahtmlpart.h
index 51c7c38b..ae7bf1e7 100644
--- a/quanta/parts/kafka/kafkahtmlpart.h
+++ b/quanta/parts/kafka/kafkahtmlpart.h
@@ -20,9 +20,9 @@
#define KAFKAHTMLPART_H
#include <kurl.h>
-#include <khtml_part.h>
-#include <khtml_events.h>
-#include <kparts/event.h>
+#include <tdehtml_part.h>
+#include <tdehtml_events.h>
+#include <tdeparts/event.h>
#include <tqstringlist.h>
#include <tqptrlist.h>
@@ -235,10 +235,10 @@ signals:
protected:
bool eventFilter(TQObject *object, TQEvent *event);
- virtual void khtmlMouseMoveEvent(khtml::MouseMoveEvent *event);
- virtual void khtmlMousePressEvent(khtml::MousePressEvent *event);
- virtual void khtmlMouseReleaseEvent(khtml::MouseReleaseEvent *event);
- virtual void khtmlDrawContentsEvent(khtml::DrawContentsEvent *event);
+ virtual void tdehtmlMouseMoveEvent(tdehtml::MouseMoveEvent *event);
+ virtual void tdehtmlMousePressEvent(tdehtml::MousePressEvent *event);
+ virtual void tdehtmlMouseReleaseEvent(tdehtml::MouseReleaseEvent *event);
+ virtual void tdehtmlDrawContentsEvent(tdehtml::DrawContentsEvent *event);
private slots:
diff --git a/quanta/parts/kafka/undoredo.cpp b/quanta/parts/kafka/undoredo.cpp
index e788a5c7..c7345467 100644
--- a/quanta/parts/kafka/undoredo.cpp
+++ b/quanta/parts/kafka/undoredo.cpp
@@ -24,10 +24,10 @@
#include <kconfig.h>
#include <kdebug.h>
#include <kiconloader.h>
-#include <ktexteditor/editinterface.h>
-#include <ktexteditor/editinterfaceext.h>
-#include <ktexteditor/selectioninterface.h>
-#include <ktexteditor/viewcursorinterface.h>
+#include <tdetexteditor/editinterface.h>
+#include <tdetexteditor/editinterfaceext.h>
+#include <tdetexteditor/selectioninterface.h>
+#include <tdetexteditor/viewcursorinterface.h>
#include <dom/dom_node.h>
#include <dom/dom_exception.h>
diff --git a/quanta/parts/kafka/wkafkapart.cpp b/quanta/parts/kafka/wkafkapart.cpp
index 39cefc8f..7ef185f4 100644
--- a/quanta/parts/kafka/wkafkapart.cpp
+++ b/quanta/parts/kafka/wkafkapart.cpp
@@ -22,13 +22,13 @@
#include <dom/dom_string.h>
#include <dom/css_stylesheet.h>
#include <kdebug.h>
-#include <khtmlview.h>
+#include <tdehtmlview.h>
#include <kstandarddirs.h>
-#include <ktexteditor/editinterface.h>
-#include <ktexteditor/selectioninterface.h>
+#include <tdetexteditor/editinterface.h>
+#include <tdetexteditor/selectioninterface.h>
#include <kstandarddirs.h>
#include <klocale.h>
-#include <kmultipledrag.h>
+#include <tdemultipledrag.h>
#include <kglobal.h>
#include <kcharsets.h>
@@ -162,7 +162,7 @@ void KafkaDocument::loadDocument(Document *doc)
//create a empty document with a basic tree : HTML, HEAD, BODY
m_kafkaPart->newDocument();
- // When loading a weird html file in khtml (e.g. without BODY or HTML), khtml takes care
+ // When loading a weird html file in tdehtml (e.g. without BODY or HTML), tdehtml takes care
// to create the necessary tags. But as we are handling directly the Nodes, we have to handle this!!
// creating and linking an empty node to the root DOM::Node (#document) and
// to HEAD, HTML, BODY
@@ -718,7 +718,7 @@ bool KafkaDocument::buildKafkaNodeFromNode(Node *node, bool insertNode)
parentNode = *node->parent->leafNode();
else if(node->parent && !node->parent->leafNode())
{
- //the parent tag was invalid and khtml refuse to insert it
+ //the parent tag was invalid and tdehtml refuse to insert it
//so impossible to inser the current node
disconnectDomNodeFromQuantaNode(newNode);
if(node->rootNode())
diff --git a/quanta/parts/kafka/wkafkapart.h b/quanta/parts/kafka/wkafkapart.h
index 9c4f3529..6c52d307 100644
--- a/quanta/parts/kafka/wkafkapart.h
+++ b/quanta/parts/kafka/wkafkapart.h
@@ -374,7 +374,7 @@ public:
void coutLinkTree(Node *node, int indent);
/**
- * In order to have khtml works whatever DTD is loaded, they must always exists
+ * In order to have tdehtml works whatever DTD is loaded, they must always exists
* and be valid.
*/
DOM::Node html, body, head;
diff --git a/quanta/parts/kafka/kafkahtmlpart.cpp b/quanta/parts/kafka/kafkahtmlpart.cpp
index 52195d83..ecdc1b8d 100644
--- a/quanta/parts/kafka/kafkahtmlpart.cpp
+++ b/quanta/parts/kafka/kafkahtmlpart.cpp
@@ -28,18 +28,18 @@
#include <kdebug.h>
#include <klocale.h>
-#include <khtmlview.h>
+#include <tdehtmlview.h>
#include <kmessagebox.h>
#include <ktrader.h>
#include <klibloader.h>
-#include <kparts/factory.h>
+#include <tdeparts/factory.h>
#include <dom/dom_node.h>
#include <dom/dom_text.h>
#include <dom/dom_exception.h>
#include <dom/dom_string.h>
#include <dom/dom2_range.h>
-#include <khtml_events.h>
-//#include <khtml_part.h>
+#include <tdehtml_events.h>
+//#include <tdehtml_part.h>
#include "kafkacommon.h"
#ifdef HEAVY_DEBUG
@@ -117,7 +117,7 @@ KafkaWidget::KafkaWidget(TQWidget *parent, TQWidget *widgetParent, KafkaDocument
//d->domdialog = new KafkaDOMTreeDialog(view(), this);
//d->domdialog->show();
#endif
//IMPORTANT:without him, no document() is created in khtmlPart
begin();
write("<html></html>");
end();
@@ -2030,7 +2030,7 @@ void KafkaWidget::postprocessCursorPosition()
makeCursorVisible();
}
-void KafkaWidget::khtmlMouseMoveEvent(khtml::MouseMoveEvent *event)
+void KafkaWidget::tdehtmlMouseMoveEvent(tdehtml::MouseMoveEvent *event)
{
DOM::Node mouseNode = event->innerNode();
@@ -2043,12 +2043,12 @@ void KafkaWidget::khtmlMouseMoveEvent(khtml::MouseMoveEvent *event)
else
view()->setCursor(TQt::arrowCursor);
- KHTMLPart::khtmlMouseMoveEvent(event);
+ KHTMLPart::tdehtmlMouseMoveEvent(event);
}
-void KafkaWidget::khtmlMouseReleaseEvent(khtml::MouseReleaseEvent *event)
+void KafkaWidget::tdehtmlMouseReleaseEvent(tdehtml::MouseReleaseEvent *event)
{
- KHTMLPart::khtmlMouseReleaseEvent(event);
+ KHTMLPart::tdehtmlMouseReleaseEvent(event);
if(m_currentNode.isNull() || m_currentNode.nodeName().string().lower() == "#document")
{
m_currentNode = w->body;
@@ -2059,9 +2059,9 @@ void KafkaWidget::khtmlMouseReleaseEvent(khtml::MouseReleaseEvent *event)
quantaApp->aTab->setCurrentNode(w->getNode(event->innerNode()));
}
-void KafkaWidget::khtmlMousePressEvent(khtml::MousePressEvent *event)
+void KafkaWidget::tdehtmlMousePressEvent(tdehtml::MousePressEvent *event)
{
- KHTMLPart::khtmlMousePressEvent(event);
+ KHTMLPart::tdehtmlMousePressEvent(event);
if(d->m_cursorOffset == 0 && !m_currentNode.isNull() &&
m_currentNode.nodeName().string().lower() == "body")
putCursorAtFirstAvailableLocation();
@@ -2071,9 +2071,9 @@ void KafkaWidget::khtmlMousePressEvent(khtml::MousePressEvent *event)
}
-void KafkaWidget::khtmlDrawContentsEvent(khtml::DrawContentsEvent *event)
+void KafkaWidget::tdehtmlDrawContentsEvent(tdehtml::DrawContentsEvent *event)
{
- KHTMLPart::khtmlDrawContentsEvent(event);
+ KHTMLPart::tdehtmlDrawContentsEvent(event);
}
void KafkaWidget::getCurrentNode(DOM::Node &_currentNode, long &offset)
@@ -117,7 +117,7 @@ KafkaWidget::KafkaWidget(TQWidget *parent, TQWidget *widgetParent, KafkaDocument
//d->domdialog->show();
#endif
- //IMPORTANT:without him, no document() is created in khtmlPart
+ //IMPORTANT:without him, no document() is created in tdehtmlPart
begin();
write("<html></html>");